@@ -31,6 +31,10 @@
 #include "heasp.h"
 #endif
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 /////////////////////////////////////////////////////////////////
 // Constants.
 /////////////////////////////////////////////////////////////////
@@ -1010,4 +1014,8 @@ int create_unique_tmp_file(char filename_template[], int* status);
     (of length at least L_tmpnam). */
 void create_unique_tmp_name(char filename_buffer[], int* status);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* SIMPUT_H */
