@@ -400,10 +400,12 @@ static void addSpecCombiToCat(struct Parameters* par, par_info *data_par, img_li
 	// Set the name of the spectrum
 	spec->name = (char*) malloc (maxStrLenCat*sizeof(char));
 	CHECK_NULL_VOID(spec->name,*status,"memory allocation failed");
-	strcpy(spec->name,"");
-	snprintf(spec->name,maxStrLenCat,"spec");
+	strncpy(spec->name, "", 1);
+	snprintf(spec->name, maxStrLenCat, "spec");
 	for (int ii=0;ii<li->num_param;ii++){
-		sprintf(spec->name,"%s_%d",spec->name,li->pval_ar[ii]);
+		char buf[maxStrLenCat];
+		strncpy(buf, spec->name, maxStrLenCat);
+		snprintf(spec->name, maxStrLenCat, "%s_%d",buf,li->pval_ar[ii]);
 	}
 	if ((int)strlen(spec->name) > maxStrLenCat) {
 		SIMPUT_ERROR("'NAME' of spectrum contains more than 64 characters");
@@ -541,9 +543,11 @@ int simputmulticell_main() {
 
 				// add source to catalog
 				// Get BASE name fomr the Param Combi (in the list)
-				strcpy(spec_name,"");
+				strncpy(spec_name,"",1);
 				for (int ii=0;ii<num_param;ii++){
-					sprintf(spec_name,"%s_%d",spec_name,id_array[ii]);
+					char buf[maxStrLenCat];
+					strncpy(buf, spec_name, maxStrLenCat);
+					snprintf(spec_name, maxStrLenCat, "%s_%d", buf, id_array[ii]);
 				}
 				snprintf(path_fspec,SIMPUT_MAXSTR,"[SPECTRUM,1][NAME=='spec%s']",spec_name);
 			}
