@@ -573,10 +573,12 @@ static void get_filenames(char **fsrc, char **fspec, char **fimg, img_list *li,i
 
 	char fname[maxStrLenCat];
 
-	strcpy(fname,"");
+	strncpy(fname,"",1);
     // Get BASE name fomr the Param Combi (in the list)
 	for (int ii=0;ii<li->num_param;ii++){
-		sprintf(fname,"%s_%i",fname,li->pval_ar[ii]);
+		char buf[maxStrLenCat];
+		strncpy(buf, fname, maxStrLenCat);
+		snprintf(fname, maxStrLenCat, "%s_%i", buf, li->pval_ar[ii]);
 	}
 
 	init_string(fsrc,fname,"src%s",status);
@@ -626,11 +628,14 @@ static void get_setPar_string_isis(char **str, par_info *data_par,img_list *li,
 
 	*str = (char*) malloc (SIMPUT_MAXSTR*sizeof(char));
 	CHECK_NULL_VOID(*str,*status,"memory allocation failed");
-	strcpy(*str,"");
+	strncpy(*str,"",1);
 	int ii;
 	for (ii=0;ii<li->num_param;ii++){
-		sprintf(*str,"%s set_par(\"%s\",%.8e);",
-				*str,
+		char buf[SIMPUT_MAXSTR];
+		strncpy(buf, *str, SIMPUT_MAXSTR);
+		snprintf(*str, SIMPUT_MAXSTR,
+				"%s set_par(\"%s\",%.8e);",
+				buf,
 				data_par[ii].par_names,
 				data_par[ii].pvals[li->pval_ar[ii]]
 			    );
@@ -641,11 +646,15 @@ static void get_setPar_string_xspec(char **str, par_info *data_par,img_list *li,
 
 	*str = (char*) malloc (SIMPUT_MAXSTR*sizeof(char));
 	CHECK_NULL_VOID(*str,*status,"memory allocation failed");
-	strcpy(*str,"");
+	strncpy(*str,"",1);
 	int ii;
 	for (ii=0;ii<li->num_param;ii++){
-		sprintf(*str,"%s newpar %s %.8e ;",
-				*str,
+		char buf[SIMPUT_MAXSTR];
+		strncpy(buf, *str, SIMPUT_MAXSTR);
+
+		snprintf(*str, SIMPUT_MAXSTR,
+				"%s newpar %s %.8e ;",
+				buf,
 				data_par[ii].par_names,
 				data_par[ii].pvals[li->pval_ar[ii]]
 			    );
