@@ -293,9 +293,15 @@ int simputspec_main()
 	break;
       }
       arf = loadARF(ancrfile, &status);
-      CHECK_STATUS_BREAK(status);
+      if (EXIT_SUCCESS != status) {
+      	SIMPUT_ERROR("could not load ARF for PHA spectrum");
+      	break;
+      }
       rmf = loadNormalizedRMF(respfile, &status);
-      CHECK_STATUS_BREAK(status);
+      if (EXIT_SUCCESS != status) {
+      	SIMPUT_ERROR("could not load RMF for PHA spectrum");
+      	break;
+      }
       loadEbounds(rmf, respfile, &status);
       CHECK_STATUS_BREAK(status);
 
